You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@isis.apache.org by da...@apache.org on 2021/03/20 07:36:23 UTC

[isis] 02/02: ISIS-2450: fixes download script to verify releases

This is an automated email from the ASF dual-hosted git repository.

danhaywood pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/isis.git

commit 04384de6f9168baf00434dfea1987e7a24082683
Author: danhaywood <da...@haywood-associates.co.uk>
AuthorDate: Sat Mar 20 07:01:32 2021 +0000

    ISIS-2450: fixes download script to verify releases
    
    (cherry picked from commit 3a5f81274cfa6f4afd99abaf241a5d395b8b21f0)
---
 scripts/verify-isis-release.sh | 59 +++++++++++++++++++-----------------------
 1 file changed, 26 insertions(+), 33 deletions(-)

diff --git a/scripts/verify-isis-release.sh b/scripts/verify-isis-release.sh
index 6ca4cc8..adc7b49 100755
--- a/scripts/verify-isis-release.sh
+++ b/scripts/verify-isis-release.sh
@@ -93,38 +93,19 @@ _build(){
 	popd
 }
 
-_download_simpleapp(){
-    APP=simpleapp
-    BRANCH=release-$VERSION-$RC
-
-    rm -rf test-$APP
-    mkdir test-$APP
-    pushd test-$APP
+_download_app(){
+    APP=$1
+    BRANCH=$2
 
     REPO=isis-app-$APP
-    curl "https://codeload.github.com/apache/$REPO/zip/$BRANCH" | jar xv
-    mv $REPO-$BRANCH $REPO
-
-    pushd $REPO
-    _execmustpass mvn clean install
-    popd; popd
-}
-
-_download_helloworld(){
-    APP=helloworld
-    BRANCH=release-$VERSION-$RC
+    DIR=$REPO-$BRANCH
 
-    rm -rf test-$APP
-    mkdir test-$APP
-    pushd test-$APP
-
-    REPO=isis-app-$APP
+    rm -rf $DIR
     curl "https://codeload.github.com/apache/$REPO/zip/$BRANCH" | jar xv
-    mv $REPO-$BRANCH $REPO
 
-    pushd $REPO
+    pushd $DIR
     _execmustpass mvn clean install
-    popd; popd
+    popd
 }
 
 
@@ -166,21 +147,33 @@ _download
 _verify
 _unpack
 _build
-_download_simpleapp
-_download_helloworld
+_download_app helloworld jdo
+_download_app helloworld jpa
+_download_app simpleapp jdo
+_download_app simpleapp jpa
 
 # print instructions for final testing
 clear
 cat <<EOF
 
-# Test out helloworld using:
-pushd test-helloworld/isis-app-helloworld
+# Test out helloworld (jdo) using:
+pushd isis-app-helloworld-jdo
 mvn spring-boot:run
 popd
 
-# Test out simpleapp using:
-pushd test-simpleapp/isis-app-simpleapp
-mvn -pl webapp spring-boot:run
+# Test out helloworld (jpa) using:
+pushd isis-app-helloworld-jpa
+mvn spring-boot:run
+popd
+
+# Test out simpleapp (jdo) using:
+pushd isis-app-simpleapp-jdo
+mvn spring-boot:run
+popd
+
+# Test out simpleapp (jpa) using:
+pushd isis-app-simpleapp-jpa
+mvn spring-boot:run
 popd
 
 EOF